@@ -58,6 +58,10 @@ sub parse_html_man_page ($html_man_page) {
         $text =~ s/\x{201c}(\w+)\x{201d}/B<$1>/g;
         # replace single utf-8 quote with ascii quote
         $text =~ s/\x{2019}/'/g;
+        # avoid long unbreakable lines
+        $text =~ s/,(\w)/, $1/g;
+        # avoid trailing whitespace
+        $text =~ s/\s+$//mg;
         push $data{element_data}{$parameter}->@*, $text if $parameter;
     };
 
@@ -93,7 +97,7 @@ sub setup_choice {
     );
 }
 
-my $ssh_host = 'type=hash index_type=string cargo type=node '
+my $ssh_host = 'type=hash index_type=string ordered=1 cargo type=node '
     .'config_class_name=Ssh::HostElement';
 my $ssh_forward = 'type=list cargo type=node config_class_name="Ssh::PortForward"';
 my $uniline = 'type=leaf value_type=uniline';
@@ -144,9 +148,14 @@ sub create_load_data ($ssh_system, $name, @desc) {
     my ($set_choice, $get_choices) = setup_choice();
 
     # handle "The argument must be B<yes>, B<no> (the default) or B<ask>."
-    if ($desc =~ /(?:argument|option)s? (?:to this keyword )?(?:are|\w+ be)([^.]+)\./i) {
+    if ($desc =~ /(?:argument|option)s? (?:to this keyword )?(?:are|\w+ be)(?: one of)?(?:[\s:]+)(?=B<)([^.]+)\./i) {
         my $str = $1;
-        $set_choice->( $str =~ /B<([\w-]+)>/g );
+        $set_choice->( $str =~ /B<(\w[\w-]*)>/g );
+    }
+
+    if ($desc =~ /supported keywords are(?:[\s:]+)(?=B<)([^.]+)\./i) {
+        my $str = $1;
+        $set_choice->( $str =~ /B<(\w[\w-]*)>/g );
     }
 
     if (my @values = ($desc =~ /(?:(?:if|when|with) (?:(?:$bold_name|th(?:e|is) option) (?:is )?)?set to|A value of|setting this to|The default(?: is|,)|Accepted values are) B<(\w+)>/gi)) {
@@ -168,9 +177,14 @@ sub create_load_data ($ssh_system, $name, @desc) {
     }
 
     if ($desc =~ /(Specif\w+|Sets?) (a|the) (maximum )?(number|timeout)/) {
-        $value_type = 'integer';
+        my $upstream_default;
         if ($desc =~ /The default(?: value)?(?: is|,) (\d+)/) {
-            push @load_extra, "upstream_default=$1";
+            $upstream_default = $1;
+        }
+        # do not set integer type when upstream default value is not an integer
+        if (not defined $upstream_default or $upstream_default =~ /^\d+$/) {
+            $value_type = 'integer';
+            push @load_extra, qq!upstream_default="$upstream_default"! if defined $upstream_default;
         }
     }
     elsif (@choices == 1) {
