@@ -11,7 +11,7 @@ use strict;
 use warnings;
 
 package Config::Model::Backend::OpenSsh::Role::Writer ;
-$Config::Model::Backend::OpenSsh::Role::Writer::VERSION = '2.8.4.2';
+$Config::Model::Backend::OpenSsh::Role::Writer::VERSION = '2.8.7.1';
 use Mouse::Role ;
 
 with 'Config::Model::Backend::OpenSsh::Role::MatchBlock';
@@ -37,13 +37,16 @@ sub ssh_write {
 
     $logger->info("writing config file $args{file_path}");
 
-    my $result = $self->write_global_comment('#') ;
+    my $comment = $self->write_global_comment('#') ;
 
-    $result .= $self->write_node_content($config_root,$args{ssh_mode});
+    my $result = $self->write_node_content($config_root,$args{ssh_mode});
 
-    $args{file_path}->spew_utf8($result);
+    if ($result) {
+        $args{file_path}->spew_utf8($comment.$result);
+        return 1;
+    }
 
-    return 1;
+    return 0;
 }
 
 
@@ -144,7 +147,7 @@ Config::Model::Backend::OpenSsh::Role::Writer - Role to write OpenSsh config fil
 
 =head1 VERSION
 
-version 2.8.4.2
+version 2.8.7.1
 
 =head1 SYNOPSIS
 
